==> native-image-base-24.0.2.jar: module-info.java <==
module org.graalvm.nativeimage.base {
    requires java.sql;
    requires java.xml;
    /* transitive */ requires jdk.graal.compiler;
    requires jdk.internal.vm.ci;
    /* transitive */ requires org.graalvm.collections;
    /* transitive */ requires org.graalvm.nativeimage;
    /* transitive */ requires org.graalvm.truffle.compiler;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.svm.common.meta to com.oracle.truffle.enterprise.svm, org.graalvm.extraimage.builder, org.graalvm.nativeimage.builder, org.graalvm.nativeimage.foreign, org.graalvm.nativeimage.llvm, org.graalvm.nativeimage.pointsto, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.common.option to com.oracle.truffle.enterprise.svm, org.graalvm.nativeimage.builder, org.graalvm.nativeimage.driver, org.graalvm.nativeimage.foreign, org.graalvm.nativeimage.pointsto, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.util to com.oracle.svm.extraimage_enterprise, com.oracle.svm.svm_enterprise, com.oracle.svm_enterprise.ml_dataset, com.oracle.truffle.enterprise.svm, org.graalvm.extraimage.builder, org.graalvm.extraimage.librarysupport, org.graalvm.nativeimage.agent.diagnostics, org.graalvm.nativeimage.agent.jvmtibase, org.graalvm.nativeimage.agent.tracing, org.graalvm.nativeimage.builder, org.graalvm.nativeimage.driver, org.graalvm.nativeimage.foreign, org.graalvm.nativeimage.junitsupport, org.graalvm.nativeimage.librarysupport, org.graalvm.nativeimage.llvm, org.graalvm.nativeimage.pointsto, org.graalvm.truffle.runtime.svm;

    provides OptionDescriptors with CommonOptions_OptionDescriptors, ImageBuildStatistics_OptionDescriptors;

}

==> native-image-base-24.1.1.jar: module-info.java <==
module org.graalvm.nativeimage.base {
    requires java.sql;
    requires java.xml;
    requires jdk.graal.compiler;
    requires jdk.internal.vm.ci;
    requires org.graalvm.collections;
    requires org.graalvm.nativeimage;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.svm.common.meta to com.oracle.truffle.enterprise.svm, org.graalvm.extraimage.builder, org.graalvm.nativeimage.builder, org.graalvm.nativeimage.foreign, org.graalvm.nativeimage.llvm, org.graalvm.nativeimage.pointsto, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.common.option to com.oracle.truffle.enterprise.svm, org.graalvm.nativeimage.builder, org.graalvm.nativeimage.driver, org.graalvm.nativeimage.foreign, org.graalvm.nativeimage.pointsto, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.util to com.oracle.svm.extraimage_enterprise, com.oracle.svm.svm_enterprise, com.oracle.svm_enterprise.ml_dataset, com.oracle.truffle.enterprise.svm, org.graalvm.extraimage.builder, org.graalvm.extraimage.librarysupport, org.graalvm.nativeimage.agent.diagnostics, org.graalvm.nativeimage.agent.jvmtibase, org.graalvm.nativeimage.agent.tracing, org.graalvm.nativeimage.builder, org.graalvm.nativeimage.driver, org.graalvm.nativeimage.foreign, org.graalvm.nativeimage.junitsupport, org.graalvm.nativeimage.librarysupport, org.graalvm.nativeimage.llvm, org.graalvm.nativeimage.pointsto, org.graalvm.truffle.runtime.svm;

    provides OptionDescriptors with ImageBuildStatistics_OptionDescriptors, CommonOptions_OptionDescriptors;

}
